.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

gentle.generators
=================

.. autosummary::
   :toctree: generators

   gentle.generators.python

.. automodule:: gentle.generators
   :members:
